[mutter/wip/carlosg/im-events: 38/38] wayland: Reword comment




commit e9db152ea5b8cbc0a29d5790998e1fb831ea8448
Author: Carlos Garnacho <carlosg gnome org>
Date:   Mon Jul 6 12:44:26 2020 +0200

    wayland: Reword comment
    
    This is no longer directly related to DBus messages, but our own event
    queue. Change the wording and use CLUTTER_PRIORITY_EVENTS to make it
    bolder, even though it's the same than G_PRIORITY_DEFAULT.
    
    https://gitlab.gnome.org/GNOME/mutter/-/merge_requests/1286

 src/wayland/meta-wayland-text-input.c | 11 ++++-------
 1 file changed, 4 insertions(+), 7 deletions(-)
---
diff --git a/src/wayland/meta-wayland-text-input.c b/src/wayland/meta-wayland-text-input.c
index 0055bf356a..d4c377b730 100644
--- a/src/wayland/meta-wayland-text-input.c
+++ b/src/wayland/meta-wayland-text-input.c
@@ -156,20 +156,17 @@ meta_wayland_text_input_focus_defer_done (ClutterInputFocus *focus)
   if (text_input->done_idle_id != 0)
     return;
 
-  /* This operates on 3 principles:
-   * - GDBus uses G_PRIORITY_DEFAULT to put messages in the thread default main
-   *   context.
-   * - All relevant ClutterInputFocus methods are ultimately backed by
-   *   DBus methods inside IBus.
+  /* This operates on 2 principles:
+   * - IM operations come as individual ClutterEvents
    * - We want to run .done after them all. The slightly lower
    *   G_PRIORITY_DEFAULT + 1 priority should ensure we at least group
    *   all messages seen so far.
    *
    * FIXME: .done may be delayed indefinitely if there's a high enough
    *        priority idle source in the main loop. It's unlikely that
    *        recurring idles run at this high priority though.
    */
-  text_input->done_idle_id = g_idle_add_full (G_PRIORITY_DEFAULT + 1,
+  text_input->done_idle_id = g_idle_add_full (CLUTTER_PRIORITY_EVENTS + 1,
                                               done_idle_cb, focus, NULL);
 }
 
@@ -156,20 +156,17 @@ meta_wayland_text_input_focus_defer_done (ClutterInputFocus *focus)
    * - We want to run .done after them all. The slightly lower
    *   G_PRIORITY_DEFAULT + 1 priority should ensure we at least group
-   *   all messages seen so far.
+   *   all events seen so far.
    *
    * FIXME: .done may be delayed indefinitely if there's a high enough


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]